@@ -94,7 +94,7 @@
 
 #define QT_FEATURE_imageio_text_loading 1
 
-#define QT_FEATURE_tslib -1
+#define QT_FEATURE_tslib 1
 
 #define QT_FEATURE_tuiotouch 1
 
@@ -126,7 +126,7 @@
 
 #define QT_FEATURE_qtgui_threadpool 1
 
-#define QT_FEATURE_graphicsframecapture -1
+#define QT_FEATURE_graphicsframecapture 1
 
 #define QT_FEATURE_wayland_client 1
 
